@@ -180,7 +180,7 @@ class _ACBaseType(abc.ABC):
         int_to_float = attr_type == float and type(value) == int
 
         value_to_set = None
-        if type_match or is_union_instance:
+        if type_match or is_union_instance or name == 'addOnCommandParameters':
             value_to_set = value
         elif is_list or is_uuid or is_union(attr_type) or is_actype_with_dict or int_to_float:
             value_to_set = _get_constructor(attr_type)(value)
